# Time series models

[![PyPI version](https://badge.fury.io/py/time-series-models.svg)](https://badge.fury.io/py/time-series-models) [![travis](https://travis-ci.org/krypton-unite/time_series_models.svg?branch=master)](https://travis-ci.org/github/krypton-unite/time-series-models) [![codecov](https://codecov.io/gh/krypton-unite/time_series_models/branch/master/graph/badge.svg)](https://codecov.io/gh/krypton-unite/time-series-models) [![GitHub license](https://img.shields.io/github/license/krypton-unite/time_series_models)](https://github.com/krypton-unite/time_series_models)

## Description
Time series neural network models for [Time series predictor](https://github.com/krypton-unite/time_series_predictor)

## Installation

```terminal
pip install time-series-models
```

## Usage